==> digiclockwdg_0.2.5-1.tar.gz: digiclockwdg-0.2.5/src/digiclock_ru.ts <==
﻿<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <location filename="digitalclockwdg.cpp" line="24"/>
        <source>Digital Clock Widget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="14"/>
        <source>Digital Clock settings</source>
        <translation type="unfinished">Настройки DigiClock</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="24"/>
        <source>Width</source>
        <translation type="unfinished">Ширина</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="48"/>
        <source>Height</source>
        <translation type="unfinished">Высота</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="72"/>
        <source>Digits Color</source>
        <translation type="unfinished">Цвет Цифр</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="93"/>
        <source>Show seconds</source>
        <translation type="unfinished">cекунды</translation>
    </message>
    <message>
        <source>Time Format</source>
        <translation type="unfinished">Формат времени</translation>
    </message>
    <message>
        <source>24H</source>
        <translation type="unfinished">24 часа</translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation type="unfinished">12 часов (am/pm)</translation>
    </message>
    <message>
        <source>Military</source>
        <translation type="unfinished">военный</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished">О программе</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished">Qt</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="unfinished">Шрифт</translation>
    </message>
    <message>
        <source>Default (LCD)</source>
        <translation type="unfinished">Исходный (LCD)</translation>
    </message>
    <message>
        <source>B</source>
        <translation type="unfinished">Ж</translation>
    </message>
    <message>
        <source>I</source>
        <translation type="unfinished">К</translation>
    </message>
    <message>
        <source>About DigiClock</source>
        <translation type="unfinished">О программе DigiClock</translation>
    </message>
    <message>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blinking Delimiter</source>
        <translation type="unfinished">Мигающий разделитель</translation>
    </message>
    <message>
        <source>&lt;b&gt;DigiClock&lt;/b&gt; 0.2.5&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing digital time</source>
        <translation type="unfinished">&lt;b&gt;DigiClock&lt;/b&gt; 0.2.5&lt;br&gt;Написано на &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Виджет, отображающий цифровое время на рабочем столе</translation>
    </message>	
</context>
</TS>

==> digiclockwdg_0.3.0.tar.gz: digiclockwdg-0.3.0/src/digiclock_ru.ts <==
﻿<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>DigitalClockWdg</name>
    <message>
        <source>Digital Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Digital Clock settings</source>
        <translation type="unfinished">Настройки DigiClock</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Ширина</translation>
    </message>
    <message>
        <source>Height</source>
        <translation type="unfinished">Высота</translation>
    </message>
    <message>
        <source>Digits Color</source>
        <translation type="unfinished">Цвет Цифр</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation type="unfinished">cекунды</translation>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished">Формат</translation>
    </message>
    <message>
        <source>24H</source>
        <translation type="unfinished">24 часа</translation>
    </message>
    <message>
        <source>12H (AM/PM)</source>
        <translation type="unfinished">12 часов (am/pm)</translation>
    </message>
    <message>
        <source>Military</source>
        <translation type="unfinished">военный</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished">О программе</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation type="unfinished">Qt</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="unfinished">Шрифт</translation>
    </message>
    <message>
        <source>Default (LCD)</source>
        <translation type="unfinished">Исходный (LCD)</translation>
    </message>
    <message>
        <source>B</source>
        <translation type="unfinished">Ж</translation>
    </message>
    <message>
        <source>I</source>
        <translation type="unfinished">К</translation>
    </message>
    <message>
        <source>About DigiClock</source>
        <translation type="unfinished">О программе DigiClock</translation>
    </message>
    <message>
        <source>12:48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blinking</source>
        <translation type="unfinished">мигание</translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation type="unfinished">Часовой пояс</translation>
    </message>	
    <message>
        <source>&lt;b&gt;DigiClock&lt;/b&gt; 0.3.0&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing digital time</source>
        <translation type="unfinished">&lt;b&gt;DigiClock&lt;/b&gt; 0.3.0&lt;br&gt;Написано на &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Виджет, отображающий цифровое время на рабочем столе</translation>
    </message>	
</context>
</TS>
